package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.util.ByteSequence;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/LOOKUPSWITCH.class */
public class LOOKUPSWITCH extends Select {
    /* JADX INFO: Access modifiers changed from: package-private */
    public LOOKUPSWITCH() {
    }

    public LOOKUPSWITCH(int[] match, InstructionHandle[] targets, InstructionHandle defaultTarget) {
        super((short) 171, match, targets, defaultTarget);
        short length = (short) (9 + (getMatchLength() * 8));
        super.setLength(length);
        setFixedLength(length);
    }

    @Override // org.apache.bcel.generic.Instruction
    public void accept(Visitor v) {
        v.visitVariableLengthInstruction(this);
        v.visitStackConsumer(this);
        v.visitBranchInstruction(this);
        v.visitSelect(this);
        v.visitLOOKUPSWITCH(this);
    }

    @Override // org.apache.bcel.generic.Select, org.apache.bcel.generic.BranchInstruction, org.apache.bcel.generic.Instruction
    public void dump(DataOutputStream out) throws IOException {
        super.dump(out);
        int matchLength = getMatchLength();
        out.writeInt(matchLength);
        for (int i = 0; i < matchLength; i++) {
            out.writeInt(super.getMatch(i));
            out.writeInt(setIndices(i, getTargetOffset(super.getTarget(i))));
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // org.apache.bcel.generic.Select, org.apache.bcel.generic.BranchInstruction, org.apache.bcel.generic.Instruction
    public void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
        super.initFromFile(bytes, wide);
        int matchLength = bytes.readInt();
        setMatchLength(matchLength);
        short fixedLength = (short) (9 + (matchLength * 8));
        setFixedLength(fixedLength);
        short length = (short) (matchLength + super.getPadding());
        super.setLength(length);
        super.setMatches(new int[matchLength]);
        super.setIndices(new int[matchLength]);
        super.setTargets(new InstructionHandle[matchLength]);
        for (int i = 0; i < matchLength; i++) {
            super.setMatch(i, bytes.readInt());
            super.setIndices(i, bytes.readInt());
        }
    }
}
